Module: DynamicAI

Defined in:
lib/dynamicAI.rb,
lib/dynamicAI/version.rb

Overview

INFINITE LEARNING LOOP #

Think of this as an infinite learning algorithm. You program an action in behaviours, or # a list of possible behaviours. Even if the list of behaviours changes ( is rewritten ), it # stores a memory of the last action it performed, and can repeat that action even though # it no longer has that script type in its known behaviour list. #

Defined Under Namespace

Classes: Error, Generate, Operate

Constant Summary collapse

VERSION =
"0.1.0"